role

package
v0.0.0-...-20466bc Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 31, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the role type in the database.
	Label = "role"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldDeleteTime holds the string denoting the delete_time field in the database.
	FieldDeleteTime = "delete_time"
	// FieldCreateTime holds the string denoting the create_time field in the database.
	FieldCreateTime = "create_time"
	// FieldUpdateTime holds the string denoting the update_time field in the database.
	FieldUpdateTime = "update_time"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldDisplayName holds the string denoting the display_name field in the database.
	FieldDisplayName = "display_name"
	// FieldRemark holds the string denoting the remark field in the database.
	FieldRemark = "remark"
	// FieldDeletedTime holds the string denoting the deleted_time field in the database.
	FieldDeletedTime = "deleted_time"
	// Table holds the table name of the role in the database.
	Table = "totoro_role"
)

Variables

var (
	Hooks        [1]ent.Hook
	Interceptors [1]ent.Interceptor
	// DefaultDeleteTime holds the default value on creation for the "delete_time" field.
	DefaultDeleteTime int64
	// DefaultCreateTime holds the default value on creation for the "create_time" field.
	DefaultCreateTime func() time.Time
	// DefaultUpdateTime holds the default value on creation for the "update_time" field.
	DefaultUpdateTime func() time.Time
	// UpdateDefaultUpdateTime holds the default value on update for the "update_time" field.
	UpdateDefaultUpdateTime func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() string
)

Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:

import _ "github.com/liukeshao/echo-admin/ent/runtime"

Columns holds all SQL columns for role fields.

Functions

func And

func And(predicates ...predicate.Role) predicate.Role

And groups predicates with the AND operator between them.

func CreateTime

func CreateTime(v time.Time) predicate.Role

CreateTime applies equality check predicate on the "create_time" field. It's identical to CreateTimeEQ.

func CreateTimeEQ

func CreateTimeEQ(v time.Time) predicate.Role

CreateTimeEQ applies the EQ predicate on the "create_time" field.

func CreateTimeGT

func CreateTimeGT(v time.Time) predicate.Role

CreateTimeGT applies the GT predicate on the "create_time" field.

func CreateTimeGTE

func CreateTimeGTE(v time.Time) predicate.Role

CreateTimeGTE applies the GTE predicate on the "create_time" field.

func CreateTimeIn

func CreateTimeIn(vs ...time.Time) predicate.Role

CreateTimeIn applies the In predicate on the "create_time" field.

func CreateTimeLT

func CreateTimeLT(v time.Time) predicate.Role

CreateTimeLT applies the LT predicate on the "create_time" field.

func CreateTimeLTE

func CreateTimeLTE(v time.Time) predicate.Role

CreateTimeLTE applies the LTE predicate on the "create_time" field.

func CreateTimeNEQ

func CreateTimeNEQ(v time.Time) predicate.Role

CreateTimeNEQ applies the NEQ predicate on the "create_time" field.

func CreateTimeNotIn

func CreateTimeNotIn(vs ...time.Time) predicate.Role

CreateTimeNotIn applies the NotIn predicate on the "create_time" field.

func DeleteTime

func DeleteTime(v int64) predicate.Role

DeleteTime applies equality check predicate on the "delete_time" field. It's identical to DeleteTimeEQ.

func DeleteTimeEQ

func DeleteTimeEQ(v int64) predicate.Role

DeleteTimeEQ applies the EQ predicate on the "delete_time" field.

func DeleteTimeGT

func DeleteTimeGT(v int64) predicate.Role

DeleteTimeGT applies the GT predicate on the "delete_time" field.

func DeleteTimeGTE

func DeleteTimeGTE(v int64) predicate.Role

DeleteTimeGTE applies the GTE predicate on the "delete_time" field.

func DeleteTimeIn

func DeleteTimeIn(vs ...int64) predicate.Role

DeleteTimeIn applies the In predicate on the "delete_time" field.

func DeleteTimeLT

func DeleteTimeLT(v int64) predicate.Role

DeleteTimeLT applies the LT predicate on the "delete_time" field.

func DeleteTimeLTE

func DeleteTimeLTE(v int64) predicate.Role

DeleteTimeLTE applies the LTE predicate on the "delete_time" field.

func DeleteTimeNEQ

func DeleteTimeNEQ(v int64) predicate.Role

DeleteTimeNEQ applies the NEQ predicate on the "delete_time" field.

func DeleteTimeNotIn

func DeleteTimeNotIn(vs ...int64) predicate.Role

DeleteTimeNotIn applies the NotIn predicate on the "delete_time" field.

func DeletedTime

func DeletedTime(v int64) predicate.Role

DeletedTime applies equality check predicate on the "deleted_time" field. It's identical to DeletedTimeEQ.

func DeletedTimeEQ

func DeletedTimeEQ(v int64) predicate.Role

DeletedTimeEQ applies the EQ predicate on the "deleted_time" field.

func DeletedTimeGT

func DeletedTimeGT(v int64) predicate.Role

DeletedTimeGT applies the GT predicate on the "deleted_time" field.

func DeletedTimeGTE

func DeletedTimeGTE(v int64) predicate.Role

DeletedTimeGTE applies the GTE predicate on the "deleted_time" field.

func DeletedTimeIn

func DeletedTimeIn(vs ...int64) predicate.Role

DeletedTimeIn applies the In predicate on the "deleted_time" field.

func DeletedTimeLT

func DeletedTimeLT(v int64) predicate.Role

DeletedTimeLT applies the LT predicate on the "deleted_time" field.

func DeletedTimeLTE

func DeletedTimeLTE(v int64) predicate.Role

DeletedTimeLTE applies the LTE predicate on the "deleted_time" field.

func DeletedTimeNEQ

func DeletedTimeNEQ(v int64) predicate.Role

DeletedTimeNEQ applies the NEQ predicate on the "deleted_time" field.

func DeletedTimeNotIn

func DeletedTimeNotIn(vs ...int64) predicate.Role

DeletedTimeNotIn applies the NotIn predicate on the "deleted_time" field.

func DisplayName

func DisplayName(v string) predicate.Role

DisplayName applies equality check predicate on the "display_name" field. It's identical to DisplayNameEQ.

func DisplayNameContains

func DisplayNameContains(v string) predicate.Role

DisplayNameContains applies the Contains predicate on the "display_name" field.

func DisplayNameContainsFold

func DisplayNameContainsFold(v string) predicate.Role

DisplayNameContainsFold applies the ContainsFold predicate on the "display_name" field.

func DisplayNameEQ

func DisplayNameEQ(v string) predicate.Role

DisplayNameEQ applies the EQ predicate on the "display_name" field.

func DisplayNameEqualFold

func DisplayNameEqualFold(v string) predicate.Role

DisplayNameEqualFold applies the EqualFold predicate on the "display_name" field.

func DisplayNameGT

func DisplayNameGT(v string) predicate.Role

DisplayNameGT applies the GT predicate on the "display_name" field.

func DisplayNameGTE

func DisplayNameGTE(v string) predicate.Role

DisplayNameGTE applies the GTE predicate on the "display_name" field.

func DisplayNameHasPrefix

func DisplayNameHasPrefix(v string) predicate.Role

DisplayNameHasPrefix applies the HasPrefix predicate on the "display_name" field.

func DisplayNameHasSuffix

func DisplayNameHasSuffix(v string) predicate.Role

DisplayNameHasSuffix applies the HasSuffix predicate on the "display_name" field.

func DisplayNameIn

func DisplayNameIn(vs ...string) predicate.Role

DisplayNameIn applies the In predicate on the "display_name" field.

func DisplayNameIsNil

func DisplayNameIsNil() predicate.Role

DisplayNameIsNil applies the IsNil predicate on the "display_name" field.

func DisplayNameLT

func DisplayNameLT(v string) predicate.Role

DisplayNameLT applies the LT predicate on the "display_name" field.

func DisplayNameLTE

func DisplayNameLTE(v string) predicate.Role

DisplayNameLTE applies the LTE predicate on the "display_name" field.

func DisplayNameNEQ

func DisplayNameNEQ(v string) predicate.Role

DisplayNameNEQ applies the NEQ predicate on the "display_name" field.

func DisplayNameNotIn

func DisplayNameNotIn(vs ...string) predicate.Role

DisplayNameNotIn applies the NotIn predicate on the "display_name" field.

func DisplayNameNotNil

func DisplayNameNotNil() predicate.Role

DisplayNameNotNil applies the NotNil predicate on the "display_name" field.

func ID

func ID(id string) predicate.Role

ID filters vertices based on their ID field.

func IDContainsFold

func IDContainsFold(id string) predicate.Role

IDContainsFold applies the ContainsFold predicate on the ID field.

func IDEQ

func IDEQ(id string) predicate.Role

IDEQ applies the EQ predicate on the ID field.

func IDEqualFold

func IDEqualFold(id string) predicate.Role

IDEqualFold applies the EqualFold predicate on the ID field.

func IDGT

func IDGT(id string) predicate.Role

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id string) predicate.Role

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...string) predicate.Role

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id string) predicate.Role

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id string) predicate.Role

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id string) predicate.Role

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...string) predicate.Role

IDNotIn applies the NotIn predicate on the ID field.

func Name

func Name(v string) predicate.Role

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Role

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Role

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Role

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Role

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Role

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Role

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Role

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Role

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Role

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Role

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Role

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Role

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Role

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Role) predicate.Role

Or groups predicates with the OR operator between them.

func Remark

func Remark(v string) predicate.Role

Remark applies equality check predicate on the "remark" field. It's identical to RemarkEQ.

func RemarkContains

func RemarkContains(v string) predicate.Role

RemarkContains applies the Contains predicate on the "remark" field.

func RemarkContainsFold

func RemarkContainsFold(v string) predicate.Role

RemarkContainsFold applies the ContainsFold predicate on the "remark" field.

func RemarkEQ

func RemarkEQ(v string) predicate.Role

RemarkEQ applies the EQ predicate on the "remark" field.

func RemarkEqualFold

func RemarkEqualFold(v string) predicate.Role

RemarkEqualFold applies the EqualFold predicate on the "remark" field.

func RemarkGT

func RemarkGT(v string) predicate.Role

RemarkGT applies the GT predicate on the "remark" field.

func RemarkGTE

func RemarkGTE(v string) predicate.Role

RemarkGTE applies the GTE predicate on the "remark" field.

func RemarkHasPrefix

func RemarkHasPrefix(v string) predicate.Role

RemarkHasPrefix applies the HasPrefix predicate on the "remark" field.

func RemarkHasSuffix

func RemarkHasSuffix(v string) predicate.Role

RemarkHasSuffix applies the HasSuffix predicate on the "remark" field.

func RemarkIn

func RemarkIn(vs ...string) predicate.Role

RemarkIn applies the In predicate on the "remark" field.

func RemarkIsNil

func RemarkIsNil() predicate.Role

RemarkIsNil applies the IsNil predicate on the "remark" field.

func RemarkLT

func RemarkLT(v string) predicate.Role

RemarkLT applies the LT predicate on the "remark" field.

func RemarkLTE

func RemarkLTE(v string) predicate.Role

RemarkLTE applies the LTE predicate on the "remark" field.

func RemarkNEQ

func RemarkNEQ(v string) predicate.Role

RemarkNEQ applies the NEQ predicate on the "remark" field.

func RemarkNotIn

func RemarkNotIn(vs ...string) predicate.Role

RemarkNotIn applies the NotIn predicate on the "remark" field.

func RemarkNotNil

func RemarkNotNil() predicate.Role

RemarkNotNil applies the NotNil predicate on the "remark" field.

func UpdateTime

func UpdateTime(v time.Time) predicate.Role

UpdateTime applies equality check predicate on the "update_time" field. It's identical to UpdateTimeEQ.

func UpdateTimeEQ

func UpdateTimeEQ(v time.Time) predicate.Role

UpdateTimeEQ applies the EQ predicate on the "update_time" field.

func UpdateTimeGT

func UpdateTimeGT(v time.Time) predicate.Role

UpdateTimeGT applies the GT predicate on the "update_time" field.

func UpdateTimeGTE

func UpdateTimeGTE(v time.Time) predicate.Role

UpdateTimeGTE applies the GTE predicate on the "update_time" field.

func UpdateTimeIn

func UpdateTimeIn(vs ...time.Time) predicate.Role

UpdateTimeIn applies the In predicate on the "update_time" field.

func UpdateTimeLT

func UpdateTimeLT(v time.Time) predicate.Role

UpdateTimeLT applies the LT predicate on the "update_time" field.

func UpdateTimeLTE

func UpdateTimeLTE(v time.Time) predicate.Role

UpdateTimeLTE applies the LTE predicate on the "update_time" field.

func UpdateTimeNEQ

func UpdateTimeNEQ(v time.Time) predicate.Role

UpdateTimeNEQ applies the NEQ predicate on the "update_time" field.

func UpdateTimeNotIn

func UpdateTimeNotIn(vs ...time.Time) predicate.Role

UpdateTimeNotIn applies the NotIn predicate on the "update_time" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Role queries.

func ByCreateTime

func ByCreateTime(opts ...sql.OrderTermOption) OrderOption

ByCreateTime orders the results by the create_time field.

func ByDeleteTime

func ByDeleteTime(opts ...sql.OrderTermOption) OrderOption

ByDeleteTime orders the results by the delete_time field.

func ByDeletedTime

func ByDeletedTime(opts ...sql.OrderTermOption) OrderOption

ByDeletedTime orders the results by the deleted_time field.

func ByDisplayName

func ByDisplayName(opts ...sql.OrderTermOption) OrderOption

ByDisplayName orders the results by the display_name field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByRemark

func ByRemark(opts ...sql.OrderTermOption) OrderOption

ByRemark orders the results by the remark field.

func ByUpdateTime

func ByUpdateTime(opts ...sql.OrderTermOption) OrderOption

ByUpdateTime orders the results by the update_time field.

Jump to