Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Role) predicate.Role
- func CreateTime(v time.Time) predicate.Role
- func CreateTimeEQ(v time.Time) predicate.Role
- func CreateTimeGT(v time.Time) predicate.Role
- func CreateTimeGTE(v time.Time) predicate.Role
- func CreateTimeIn(vs ...time.Time) predicate.Role
- func CreateTimeLT(v time.Time) predicate.Role
- func CreateTimeLTE(v time.Time) predicate.Role
- func CreateTimeNEQ(v time.Time) predicate.Role
- func CreateTimeNotIn(vs ...time.Time) predicate.Role
- func DeleteTime(v int64) predicate.Role
- func DeleteTimeEQ(v int64) predicate.Role
- func DeleteTimeGT(v int64) predicate.Role
- func DeleteTimeGTE(v int64) predicate.Role
- func DeleteTimeIn(vs ...int64) predicate.Role
- func DeleteTimeLT(v int64) predicate.Role
- func DeleteTimeLTE(v int64) predicate.Role
- func DeleteTimeNEQ(v int64) predicate.Role
- func DeleteTimeNotIn(vs ...int64) predicate.Role
- func DeletedTime(v int64) predicate.Role
- func DeletedTimeEQ(v int64) predicate.Role
- func DeletedTimeGT(v int64) predicate.Role
- func DeletedTimeGTE(v int64) predicate.Role
- func DeletedTimeIn(vs ...int64) predicate.Role
- func DeletedTimeLT(v int64) predicate.Role
- func DeletedTimeLTE(v int64) predicate.Role
- func DeletedTimeNEQ(v int64) predicate.Role
- func DeletedTimeNotIn(vs ...int64) predicate.Role
- func DisplayName(v string) predicate.Role
- func DisplayNameContains(v string) predicate.Role
- func DisplayNameContainsFold(v string) predicate.Role
- func DisplayNameEQ(v string) predicate.Role
- func DisplayNameEqualFold(v string) predicate.Role
- func DisplayNameGT(v string) predicate.Role
- func DisplayNameGTE(v string) predicate.Role
- func DisplayNameHasPrefix(v string) predicate.Role
- func DisplayNameHasSuffix(v string) predicate.Role
- func DisplayNameIn(vs ...string) predicate.Role
- func DisplayNameIsNil() predicate.Role
- func DisplayNameLT(v string) predicate.Role
- func DisplayNameLTE(v string) predicate.Role
- func DisplayNameNEQ(v string) predicate.Role
- func DisplayNameNotIn(vs ...string) predicate.Role
- func DisplayNameNotNil() predicate.Role
- func ID(id string) predicate.Role
- func IDContainsFold(id string) predicate.Role
- func IDEQ(id string) predicate.Role
- func IDEqualFold(id string) predicate.Role
- func IDGT(id string) predicate.Role
- func IDGTE(id string) predicate.Role
- func IDIn(ids ...string) predicate.Role
- func IDLT(id string) predicate.Role
- func IDLTE(id string) predicate.Role
- func IDNEQ(id string) predicate.Role
- func IDNotIn(ids ...string) predicate.Role
- func Name(v string) predicate.Role
- func NameContains(v string) predicate.Role
- func NameContainsFold(v string) predicate.Role
- func NameEQ(v string) predicate.Role
- func NameEqualFold(v string) predicate.Role
- func NameGT(v string) predicate.Role
- func NameGTE(v string) predicate.Role
- func NameHasPrefix(v string) predicate.Role
- func NameHasSuffix(v string) predicate.Role
- func NameIn(vs ...string) predicate.Role
- func NameLT(v string) predicate.Role
- func NameLTE(v string) predicate.Role
- func NameNEQ(v string) predicate.Role
- func NameNotIn(vs ...string) predicate.Role
- func Not(p predicate.Role) predicate.Role
- func Or(predicates ...predicate.Role) predicate.Role
- func Remark(v string) predicate.Role
- func RemarkContains(v string) predicate.Role
- func RemarkContainsFold(v string) predicate.Role
- func RemarkEQ(v string) predicate.Role
- func RemarkEqualFold(v string) predicate.Role
- func RemarkGT(v string) predicate.Role
- func RemarkGTE(v string) predicate.Role
- func RemarkHasPrefix(v string) predicate.Role
- func RemarkHasSuffix(v string) predicate.Role
- func RemarkIn(vs ...string) predicate.Role
- func RemarkIsNil() predicate.Role
- func RemarkLT(v string) predicate.Role
- func RemarkLTE(v string) predicate.Role
- func RemarkNEQ(v string) predicate.Role
- func RemarkNotIn(vs ...string) predicate.Role
- func RemarkNotNil() predicate.Role
- func UpdateTime(v time.Time) predicate.Role
- func UpdateTimeEQ(v time.Time) predicate.Role
- func UpdateTimeGT(v time.Time) predicate.Role
- func UpdateTimeGTE(v time.Time) predicate.Role
- func UpdateTimeIn(vs ...time.Time) predicate.Role
- func UpdateTimeLT(v time.Time) predicate.Role
- func UpdateTimeLTE(v time.Time) predicate.Role
- func UpdateTimeNEQ(v time.Time) predicate.Role
- func UpdateTimeNotIn(vs ...time.Time) predicate.Role
- func ValidColumn(column string) bool
- type OrderOption
- func ByCreateTime(opts ...sql.OrderTermOption) OrderOption
- func ByDeleteTime(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedTime(opts ...sql.OrderTermOption) OrderOption
- func ByDisplayName(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByRemark(opts ...sql.OrderTermOption) OrderOption
- func ByUpdateTime(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the role type in the database. Label = "role" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldDeleteTime holds the string denoting the delete_time field in the database. FieldDeleteTime = "delete_time" // FieldCreateTime holds the string denoting the create_time field in the database. FieldCreateTime = "create_time" // FieldUpdateTime holds the string denoting the update_time field in the database. FieldUpdateTime = "update_time" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldDisplayName holds the string denoting the display_name field in the database. FieldDisplayName = "display_name" // FieldRemark holds the string denoting the remark field in the database. FieldRemark = "remark" // FieldDeletedTime holds the string denoting the deleted_time field in the database. FieldDeletedTime = "deleted_time" // Table holds the table name of the role in the database. Table = "totoro_role" )
Variables ¶
var ( Hooks [1]ent.Hook Interceptors [1]ent.Interceptor // DefaultDeleteTime holds the default value on creation for the "delete_time" field. DefaultDeleteTime int64 // DefaultCreateTime holds the default value on creation for the "create_time" field. DefaultCreateTime func() time.Time // DefaultUpdateTime holds the default value on creation for the "update_time" field. DefaultUpdateTime func() time.Time // UpdateDefaultUpdateTime holds the default value on update for the "update_time" field. UpdateDefaultUpdateTime func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() string )
Note that the variables below are initialized by the runtime package on the initialization of the application. Therefore, it should be imported in the main as follows:
import _ "github.com/liukeshao/echo-admin/ent/runtime"
var Columns = []string{ FieldID, FieldDeleteTime, FieldCreateTime, FieldUpdateTime, FieldName, FieldDisplayName, FieldRemark, FieldDeletedTime, }
Columns holds all SQL columns for role fields.
Functions ¶
func CreateTime ¶
CreateTime applies equality check predicate on the "create_time" field. It's identical to CreateTimeEQ.
func CreateTimeEQ ¶
CreateTimeEQ applies the EQ predicate on the "create_time" field.
func CreateTimeGT ¶
CreateTimeGT applies the GT predicate on the "create_time" field.
func CreateTimeGTE ¶
CreateTimeGTE applies the GTE predicate on the "create_time" field.
func CreateTimeIn ¶
CreateTimeIn applies the In predicate on the "create_time" field.
func CreateTimeLT ¶
CreateTimeLT applies the LT predicate on the "create_time" field.
func CreateTimeLTE ¶
CreateTimeLTE applies the LTE predicate on the "create_time" field.
func CreateTimeNEQ ¶
CreateTimeNEQ applies the NEQ predicate on the "create_time" field.
func CreateTimeNotIn ¶
CreateTimeNotIn applies the NotIn predicate on the "create_time" field.
func DeleteTime ¶
DeleteTime applies equality check predicate on the "delete_time" field. It's identical to DeleteTimeEQ.
func DeleteTimeEQ ¶
DeleteTimeEQ applies the EQ predicate on the "delete_time" field.
func DeleteTimeGT ¶
DeleteTimeGT applies the GT predicate on the "delete_time" field.
func DeleteTimeGTE ¶
DeleteTimeGTE applies the GTE predicate on the "delete_time" field.
func DeleteTimeIn ¶
DeleteTimeIn applies the In predicate on the "delete_time" field.
func DeleteTimeLT ¶
DeleteTimeLT applies the LT predicate on the "delete_time" field.
func DeleteTimeLTE ¶
DeleteTimeLTE applies the LTE predicate on the "delete_time" field.
func DeleteTimeNEQ ¶
DeleteTimeNEQ applies the NEQ predicate on the "delete_time" field.
func DeleteTimeNotIn ¶
DeleteTimeNotIn applies the NotIn predicate on the "delete_time" field.
func DeletedTime ¶
DeletedTime applies equality check predicate on the "deleted_time" field. It's identical to DeletedTimeEQ.
func DeletedTimeEQ ¶
DeletedTimeEQ applies the EQ predicate on the "deleted_time" field.
func DeletedTimeGT ¶
DeletedTimeGT applies the GT predicate on the "deleted_time" field.
func DeletedTimeGTE ¶
DeletedTimeGTE applies the GTE predicate on the "deleted_time" field.
func DeletedTimeIn ¶
DeletedTimeIn applies the In predicate on the "deleted_time" field.
func DeletedTimeLT ¶
DeletedTimeLT applies the LT predicate on the "deleted_time" field.
func DeletedTimeLTE ¶
DeletedTimeLTE applies the LTE predicate on the "deleted_time" field.
func DeletedTimeNEQ ¶
DeletedTimeNEQ applies the NEQ predicate on the "deleted_time" field.
func DeletedTimeNotIn ¶
DeletedTimeNotIn applies the NotIn predicate on the "deleted_time" field.
func DisplayName ¶
DisplayName applies equality check predicate on the "display_name" field. It's identical to DisplayNameEQ.
func DisplayNameContains ¶
DisplayNameContains applies the Contains predicate on the "display_name" field.
func DisplayNameContainsFold ¶
DisplayNameContainsFold applies the ContainsFold predicate on the "display_name" field.
func DisplayNameEQ ¶
DisplayNameEQ applies the EQ predicate on the "display_name" field.
func DisplayNameEqualFold ¶
DisplayNameEqualFold applies the EqualFold predicate on the "display_name" field.
func DisplayNameGT ¶
DisplayNameGT applies the GT predicate on the "display_name" field.
func DisplayNameGTE ¶
DisplayNameGTE applies the GTE predicate on the "display_name" field.
func DisplayNameHasPrefix ¶
DisplayNameHasPrefix applies the HasPrefix predicate on the "display_name" field.
func DisplayNameHasSuffix ¶
DisplayNameHasSuffix applies the HasSuffix predicate on the "display_name" field.
func DisplayNameIn ¶
DisplayNameIn applies the In predicate on the "display_name" field.
func DisplayNameIsNil ¶
DisplayNameIsNil applies the IsNil predicate on the "display_name" field.
func DisplayNameLT ¶
DisplayNameLT applies the LT predicate on the "display_name" field.
func DisplayNameLTE ¶
DisplayNameLTE applies the LTE predicate on the "display_name" field.
func DisplayNameNEQ ¶
DisplayNameNEQ applies the NEQ predicate on the "display_name" field.
func DisplayNameNotIn ¶
DisplayNameNotIn applies the NotIn predicate on the "display_name" field.
func DisplayNameNotNil ¶
DisplayNameNotNil applies the NotNil predicate on the "display_name" field.
func IDContainsFold ¶
IDContainsFold applies the ContainsFold predicate on the ID field.
func IDEqualFold ¶
IDEqualFold applies the EqualFold predicate on the ID field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func Remark ¶
Remark applies equality check predicate on the "remark" field. It's identical to RemarkEQ.
func RemarkContains ¶
RemarkContains applies the Contains predicate on the "remark" field.
func RemarkContainsFold ¶
RemarkContainsFold applies the ContainsFold predicate on the "remark" field.
func RemarkEqualFold ¶
RemarkEqualFold applies the EqualFold predicate on the "remark" field.
func RemarkHasPrefix ¶
RemarkHasPrefix applies the HasPrefix predicate on the "remark" field.
func RemarkHasSuffix ¶
RemarkHasSuffix applies the HasSuffix predicate on the "remark" field.
func RemarkIsNil ¶
RemarkIsNil applies the IsNil predicate on the "remark" field.
func RemarkNotIn ¶
RemarkNotIn applies the NotIn predicate on the "remark" field.
func RemarkNotNil ¶
RemarkNotNil applies the NotNil predicate on the "remark" field.
func UpdateTime ¶
UpdateTime applies equality check predicate on the "update_time" field. It's identical to UpdateTimeEQ.
func UpdateTimeEQ ¶
UpdateTimeEQ applies the EQ predicate on the "update_time" field.
func UpdateTimeGT ¶
UpdateTimeGT applies the GT predicate on the "update_time" field.
func UpdateTimeGTE ¶
UpdateTimeGTE applies the GTE predicate on the "update_time" field.
func UpdateTimeIn ¶
UpdateTimeIn applies the In predicate on the "update_time" field.
func UpdateTimeLT ¶
UpdateTimeLT applies the LT predicate on the "update_time" field.
func UpdateTimeLTE ¶
UpdateTimeLTE applies the LTE predicate on the "update_time" field.
func UpdateTimeNEQ ¶
UpdateTimeNEQ applies the NEQ predicate on the "update_time" field.
func UpdateTimeNotIn ¶
UpdateTimeNotIn applies the NotIn predicate on the "update_time" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Role queries.
func ByCreateTime ¶
func ByCreateTime(opts ...sql.OrderTermOption) OrderOption
ByCreateTime orders the results by the create_time field.
func ByDeleteTime ¶
func ByDeleteTime(opts ...sql.OrderTermOption) OrderOption
ByDeleteTime orders the results by the delete_time field.
func ByDeletedTime ¶
func ByDeletedTime(opts ...sql.OrderTermOption) OrderOption
ByDeletedTime orders the results by the deleted_time field.
func ByDisplayName ¶
func ByDisplayName(opts ...sql.OrderTermOption) OrderOption
ByDisplayName orders the results by the display_name field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByRemark ¶
func ByRemark(opts ...sql.OrderTermOption) OrderOption
ByRemark orders the results by the remark field.
func ByUpdateTime ¶
func ByUpdateTime(opts ...sql.OrderTermOption) OrderOption
ByUpdateTime orders the results by the update_time field.